/*******************************************************************************
* File Name: AnalogFilter_1_FILTERAGND2SAR_BUFFER.h
* Version 1.20
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Opamp (Analog Buffer) Component.
*
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_OPAMP_AnalogFilter_1_FILTERAGND2SAR_BUFFER_H)
#define CY_OPAMP_AnalogFilter_1_FILTERAGND2SAR_BUFFER_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
*       Type Definitions
***************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} AnalogFilter_1_FILTERAGND2SAR_BUFFER_BACKUP_STRUCT;


/**************************************
*        Function Prototypes
**************************************/
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Init(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Enable(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Start(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Stop(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_SetPower(uint32 power);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_PumpControl(uint32 onOff);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Sleep(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_Wakeup(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_SaveConfig(void);
void AnalogFilter_1_FILTERAGND2SAR_BUFFER_RestoreConfig(void);


/**************************************
*           API Constants
**************************************/

/* Parameters for SetPower() function */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_LOW_POWER      (1u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_MED_POWER      (2u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_HIGH_POWER     (3u)


/* Parameters for PumpControl() function */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMP_ON        (1u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMP_OFF       (0u)


/***************************************
*   Initial Parameter Constants
****************************************/

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OUTPUT_CURRENT         (1u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_POWER                  (3u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_MODE                   (1u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_TRIM_VALUE     (3u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEEPSLEEP_SUPPORT      (0u)


/***************************************
*    Variables with External Linkage
***************************************/

extern uint8  AnalogFilter_1_FILTERAGND2SAR_BUFFER_initVar;


/**************************************
*             Registers
**************************************/

#ifdef CYIPBLOCK_m0s8pass4b_VERSION
    #define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_REG       (*(reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__CTB_CTB_CTRL)
    #define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_PTR       ( (reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__CTB_CTB_CTRL)
#else
    #define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_REG       (*(reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__CTBM_CTB_CTRL)
    #define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_PTR       ( (reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__CTBM_CTB_CTRL)
#endif /* CYIPBLOCK_m0s8pass4b_VERSION */

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL_REG    (*(reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__OA_RES_CTRL)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL_PTR    ( (reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__OA_RES_CTRL)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_TRIM_REG   (*(reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__OA_COMP_TRIM)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_TRIM_PTR   ( (reg32 *) AnalogFilter_1_FILTERAGND2SAR_BUFFER_cy_psoc4_abuf__OA_COMP_TRIM)


/***************************************
*        Registers Constants
***************************************/

/* AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_REG */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_DEEPSLEEP_ON_SHIFT    (30u)   /* [30] Selects behavior CTB IP in the DeepSleep power mode */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_ENABLED_SHIFT         (31u)   /* [31] Enable of the CTB IP */


#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_DEEPSLEEP_ON          ((uint32) 0x01u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_DEEPSLEEP_ON_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_ENABLED               ((uint32) 0x01u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_ENABLED_SHIFT)


/* AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL_REG */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_SHIFT          (0u)    /* [1:0]    Power level */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_SHIFT     (2u)    /* [2]      Opamp output strenght select: 0 - 1x, 1 - 10x */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_EN_SHIFT           (4u)    /* [4]      CTB IP mode: 0 - Opamp, 1 - Comparator  */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_EN_SHIFT           (11u)   /* [11]     Pump enable */


#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE                ((uint32) 0x02u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_MASK           ((uint32) 0x03u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_1X        ((uint32) 0x00u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_10X       ((uint32) 0x01u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_MASK      ((uint32) 0x01u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_EN                 ((uint32) 0x00u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_EN_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_EN                 ((uint32) 0x01u << AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_EN_SHIFT)


/***************************************
*       Init Macros Definitions
***************************************/

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_GET_DEEPSLEEP_ON(deepSleep)    ((0u != (deepSleep)) ? (AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_DEEPSLEEP_ON) : (0u))
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_GET_OA_DRIVE_STR(current)      ((0u != (current)) ? (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_10X) : \
                                                                             (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_DRIVE_STR_SEL_1X))
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_GET_OA_PWR_MODE(mode)          ((mode) & AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_MASK)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CHECK_PWR_MODE_OFF             (0u != (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL_REG & \
                                                                AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PWR_MODE_MASK))

/* Returns true if component available in Deep Sleep power mode*/ 
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_CHECK_DEEPSLEEP_SUPPORT        (0u != AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEEPSLEEP_SUPPORT) 

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEFAULT_CTB_CTRL (AnalogFilter_1_FILTERAGND2SAR_BUFFER_GET_DEEPSLEEP_ON(AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEEPSLEEP_SUPPORT) | \
                                           AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_ENABLED)

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEFAULT_OA_RES_CTRL (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_EN | \
                                              AnalogFilter_1_FILTERAGND2SAR_BUFFER_GET_OA_DRIVE_STR(AnalogFilter_1_FILTERAGND2SAR_BUFFER_OUTPUT_CURRENT))

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_DEFAULT_OA_COMP_TRIM_REG (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_COMP_TRIM_VALUE)


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_LOWPOWER                   (AnalogFilter_1_FILTERAGND2SAR_BUFFER_LOW_POWER)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_MEDPOWER                   (AnalogFilter_1_FILTERAGND2SAR_BUFFER_MED_POWER)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_HIGHPOWER                  (AnalogFilter_1_FILTERAGND2SAR_BUFFER_HIGH_POWER)

/* PUMP ON/OFF defines */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMPON                     (AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMP_ON)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMPOFF                    (AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMP_OFF)

#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_CTRL                    (AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_REG)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL                (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_RES_CTRL_REG)

/* Bit Field  OA_CTRL */
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_CTB_EN_SHIFT            (AnalogFilter_1_FILTERAGND2SAR_BUFFER_CTB_CTRL_ENABLED_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_CTRL_SHIFT         (AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_EN_SHIFT)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_OA_PUMP_EN_MASK            (0x800u)
#define AnalogFilter_1_FILTERAGND2SAR_BUFFER_PUMP_PROTECT_MASK          (1u)


#endif    /* CY_OPAMP_AnalogFilter_1_FILTERAGND2SAR_BUFFER_H */


/* [] END OF FILE */
