/*******************************************************************************
* File Name: AnalogFilter_1_filterVinMux.c
* Version 1.80
*
*  Description:
*    This file contains all functions required for the analog multiplexer
*    AMux User Module.
*
*   Note:
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "AnalogFilter_1_filterVinMux.h"

static uint8 AnalogFilter_1_filterVinMux_lastChannel = AnalogFilter_1_filterVinMux_NULL_CHANNEL;


/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_Start
********************************************************************************
* Summary:
*  Disconnect all channels.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_Start(void) 
{
    uint8 chan;

    for(chan = 0u; chan < AnalogFilter_1_filterVinMux_CHANNELS ; chan++)
    {
#if (AnalogFilter_1_filterVinMux_MUXTYPE == AnalogFilter_1_filterVinMux_MUX_SINGLE)
        AnalogFilter_1_filterVinMux_Unset(chan);
#else
        AnalogFilter_1_filterVinMux_CYAMUXSIDE_A_Unset(chan);
        AnalogFilter_1_filterVinMux_CYAMUXSIDE_B_Unset(chan);
#endif
    }

    AnalogFilter_1_filterVinMux_lastChannel = AnalogFilter_1_filterVinMux_NULL_CHANNEL;
}


#if (!AnalogFilter_1_filterVinMux_ATMOSTONE)
/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_Select
********************************************************************************
* Summary:
*  This functions first disconnects all channels then connects the given
*  channel.
*
* Parameters:
*  channel:  The channel to connect to the common terminal.
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_Select(uint8 channel) 
{
    AnalogFilter_1_filterVinMux_DisconnectAll();        /* Disconnect all previous connections */
    AnalogFilter_1_filterVinMux_Connect(channel);       /* Make the given selection */
    AnalogFilter_1_filterVinMux_lastChannel = channel;  /* Update last channel */
}
#endif


/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_FastSelect
********************************************************************************
* Summary:
*  This function first disconnects the last connection made with FastSelect or
*  Select, then connects the given channel. The FastSelect function is similar
*  to the Select function, except it is faster since it only disconnects the
*  last channel selected rather than all channels.
*
* Parameters:
*  channel:  The channel to connect to the common terminal.
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_FastSelect(uint8 channel) 
{
    /* Disconnect the last valid channel */
    if( AnalogFilter_1_filterVinMux_lastChannel != AnalogFilter_1_filterVinMux_NULL_CHANNEL)
    {
        AnalogFilter_1_filterVinMux_Disconnect(AnalogFilter_1_filterVinMux_lastChannel);
    }

    /* Make the new channel connection */
#if (AnalogFilter_1_filterVinMux_MUXTYPE == AnalogFilter_1_filterVinMux_MUX_SINGLE)
    AnalogFilter_1_filterVinMux_Set(channel);
#else
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_A_Set(channel);
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_B_Set(channel);
#endif


    AnalogFilter_1_filterVinMux_lastChannel = channel;   /* Update last channel */
}


#if (AnalogFilter_1_filterVinMux_MUXTYPE == AnalogFilter_1_filterVinMux_MUX_DIFF)
#if (!AnalogFilter_1_filterVinMux_ATMOSTONE)
/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_Connect
********************************************************************************
* Summary:
*  This function connects the given channel without affecting other connections.
*
* Parameters:
*  channel:  The channel to connect to the common terminal.
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_Connect(uint8 channel) 
{
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_A_Set(channel);
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_B_Set(channel);
}
#endif

/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_Disconnect
********************************************************************************
* Summary:
*  This function disconnects the given channel from the common or output
*  terminal without affecting other connections.
*
* Parameters:
*  channel:  The channel to disconnect from the common terminal.
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_Disconnect(uint8 channel) 
{
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_A_Unset(channel);
    AnalogFilter_1_filterVinMux_CYAMUXSIDE_B_Unset(channel);
}
#endif

#if (AnalogFilter_1_filterVinMux_ATMOSTONE)
/*******************************************************************************
* Function Name: AnalogFilter_1_filterVinMux_DisconnectAll
********************************************************************************
* Summary:
*  This function disconnects all channels.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void AnalogFilter_1_filterVinMux_DisconnectAll(void) 
{
    if(AnalogFilter_1_filterVinMux_lastChannel != AnalogFilter_1_filterVinMux_NULL_CHANNEL) 
    {
        AnalogFilter_1_filterVinMux_Disconnect(AnalogFilter_1_filterVinMux_lastChannel);
        AnalogFilter_1_filterVinMux_lastChannel = AnalogFilter_1_filterVinMux_NULL_CHANNEL;
    }
}
#endif

/* [] END OF FILE */
