/*******************************************************************************
* File Name: FSK_Dig_Out.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "FSK_Dig_Out.h"

static FSK_Dig_Out_BACKUP_STRUCT  FSK_Dig_Out_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: FSK_Dig_Out_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet FSK_Dig_Out_SUT.c usage_FSK_Dig_Out_Sleep_Wakeup
*******************************************************************************/
void FSK_Dig_Out_Sleep(void)
{
    #if defined(FSK_Dig_Out__PC)
        FSK_Dig_Out_backup.pcState = FSK_Dig_Out_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            FSK_Dig_Out_backup.usbState = FSK_Dig_Out_CR1_REG;
            FSK_Dig_Out_USB_POWER_REG |= FSK_Dig_Out_USBIO_ENTER_SLEEP;
            FSK_Dig_Out_CR1_REG &= FSK_Dig_Out_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(FSK_Dig_Out__SIO)
        FSK_Dig_Out_backup.sioState = FSK_Dig_Out_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        FSK_Dig_Out_SIO_REG &= (uint32)(~FSK_Dig_Out_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: FSK_Dig_Out_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to FSK_Dig_Out_Sleep() for an example usage.
*******************************************************************************/
void FSK_Dig_Out_Wakeup(void)
{
    #if defined(FSK_Dig_Out__PC)
        FSK_Dig_Out_PC = FSK_Dig_Out_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            FSK_Dig_Out_USB_POWER_REG &= FSK_Dig_Out_USBIO_EXIT_SLEEP_PH1;
            FSK_Dig_Out_CR1_REG = FSK_Dig_Out_backup.usbState;
            FSK_Dig_Out_USB_POWER_REG &= FSK_Dig_Out_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(FSK_Dig_Out__SIO)
        FSK_Dig_Out_SIO_REG = FSK_Dig_Out_backup.sioState;
    #endif
}


/* [] END OF FILE */
