/***************************************************************************//**
* \file     Filter_1.c
* \version  1.10
*
* \brief
* Provides the source code to the API for the Filter_1 Component.
*
********************************************************************************
* \copyright
* (c) 2018, Cypress Semiconductor Corporation. All rights reserved.
* This software, including source code, documentation and related
* materials ("Software"), is owned by Cypress Semiconductor
* Corporation ("Cypress") and is protected by and subject to worldwide
* patent protection (United States and foreign), United States copyright
* laws and international treaty provisions. Therefore, you may use this
* Software only as provided in the license agreement accompanying the
* software package from which you obtained this Software ("EULA").
* If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
* non-transferable license to copy, modify, and compile the
* Software source code solely for use in connection with Cypress's
* integrated circuit products. Any reproduction, modification, translation,
* compilation, or representation of this Software except as specified
* above is prohibited without the express written permission of Cypress.
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO
* WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING,
* BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE. Cypress reserves the right to make
* changes to the Software without notice. Cypress does not assume any
* liability arising out of the application or use of the Software or any
* product or circuit described in the Software. Cypress does not
* authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer
* of such system or application assumes all risk of such use and in doing
* so agrees to indemnify Cypress against all liability.
*******************************************************************************/

#include "Filter_1.h"

static void Filter_1_SetupComparatorTrim(void);
static void Filter_1_UndoComparatorTrimSetup(void);
static uint32 Filter_1_FindAgndTrimDirection(void);
static uint32 Filter_1_RaiseOpampTrimToCrossing(uint32 startTrim);
static uint32 Filter_1_LowerOpampTrimToCrossing(uint32 startTrim);
static uint32 Filter_1_RaiseAgndTrimToCrossing(uint32 startTrim);
static uint32 Filter_1_LowerAgndTrimToCrossing(uint32 startTrim);
static uint32 Filter_1_SetOpampAndAgndTrim(uint32 opampTrim, uint32 agndTrim);
static uint32 Filter_1_SetOpampTrim(uint32 opampTrim);
static uint32 Filter_1_SetAgndTrim(uint32 agndTrim);
static uint32 Filter_1_IncOpampTrim(uint32 trim);
static uint32 Filter_1_DecOpampTrim(uint32 trim);
static uint32 Filter_1_IncAgndTrim(uint32 trim);
static uint32 Filter_1_DecAgndTrim(uint32 trim);

uint8 Filter_1_initVar = 0U;

#define Filter_1_UABH_A_FILTER_INITPAIRSSIZE    (18UL)

const static CyUAB_reg_pair Filter_1_UABH_A_FILTER_initPairs[Filter_1_UABH_A_FILTER_INITPAIRSSIZE] =
{
    /* OA_CTRL default always first element in initPairs */
    /* Topology-invariant registers */
     {Filter_1_UABH_A_OA_CTRL_PTR        , ((uint32)Filter_1_UABH_A_DEFAULT_OA_CTRL)}
    ,{Filter_1_UABH_A_SW_STATIC_PTR      , ((uint32)Filter_1_UABH_A_DEFAULT_SW_STATIC)}
    ,{Filter_1_UABH_A_SW_MODBIT_SRC_PTR  , ((uint32)Filter_1_UABH_A_INVAR_SW_MODBIT_SRC)}
    ,{Filter_1_UABH_A_SRAM_CTRL_PTR      , ((uint32)Filter_1_UABH_A_INVAR_SRAM_CTRL)}
    ,{Filter_1_UABH_A_SW_BOOST_CTRL_PTR  , ((uint32)Filter_1_UABH_A_DEFAULT_SW_BOOST_CTRL)}
    ,{Filter_1_UABH_A_SW_OTHER_PTR       , ((uint32)Filter_1_UABH_A_DEFAULT_SW_OTHER)}

    #if (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)
        /* Filter-invariant registers */
        ,{Filter_1_UABH_A_SW_CA_IN0_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CA_IN0)}
        ,{Filter_1_UABH_A_SW_CA_IN1_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CA_IN1)}
        ,{Filter_1_UABH_A_SW_CA_TOP_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CA_TOP)}
        ,{Filter_1_UABH_A_SW_CC_IN0_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CC_IN0)}
        ,{Filter_1_UABH_A_SW_CC_IN1_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CC_IN1)}
        ,{Filter_1_UABH_A_SW_CF_BOT_PTR      , ((uint32)Filter_1_UABH_A_LOWQSTAT_SW_CF_BOT)}

        /* Parameter-based registers */
        ,{Filter_1_UABH_A_CAP_CTRL_PTR       , ((uint32)Filter_1_UABH_A_LOWQDYN_CAP_CTRL)}
        ,{Filter_1_UABH_A_SW_CB_IN0_PTR      , ((uint32)Filter_1_UABH_A_LOWQDYN_SW_CB_IN0)}
        ,{Filter_1_UABH_A_SW_CB_IN1_PTR      , ((uint32)Filter_1_UABH_A_LOWQDYN_SW_CB_IN1)}
        ,{Filter_1_UABH_A_SW_CB_TOP_PTR      , ((uint32)Filter_1_UABH_A_LOWQDYN_SW_CB_TOP)}
        ,{Filter_1_UABH_A_SW_CC_TOP_PTR      , ((uint32)Filter_1_UABH_A_LOWQDYN_SW_CC_TOP)}
        ,{Filter_1_UABH_A_CAP_ABCF_VAL_PTR   , ((uint32)Filter_1_UABH_A_LOWQDYN_CAP_ABCF_VAL)}
    #elif (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_HIGH_Q)
        /* Filter-invariant registers */
        ,{Filter_1_UABH_A_SW_CA_IN0_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CA_IN0)}
        ,{Filter_1_UABH_A_SW_CA_IN1_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CA_IN1)}
        ,{Filter_1_UABH_A_SW_CA_TOP_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CA_TOP)}
        ,{Filter_1_UABH_A_SW_CB_IN0_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CB_IN0)}
        ,{Filter_1_UABH_A_SW_CB_IN1_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CB_IN1)}
        ,{Filter_1_UABH_A_SW_CC_IN0_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN0)}
        ,{Filter_1_UABH_A_SW_CC_IN1_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN1)}
        ,{Filter_1_UABH_A_SW_CC_TOP_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CC_TOP)}
        ,{Filter_1_UABH_A_SW_CF_BOT_PTR      , ((uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CF_BOT)}

        /* Parameter-based registers */
        ,{Filter_1_UABH_A_CAP_CTRL_PTR       , ((uint32)Filter_1_UABH_A_HIGHQDYN_CAP_CTRL)}
        ,{Filter_1_UABH_A_SW_CB_TOP_PTR      , ((uint32)Filter_1_UABH_A_HIGHQDYN_SW_CB_TOP)}
        ,{Filter_1_UABH_A_CAP_ABCF_VAL_PTR   , ((uint32)Filter_1_UABH_A_HIGHQDYN_CAP_ABCF_VAL)}
    #endif /* (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q) */
};

#define Filter_1_UABH_B_FILTER_INITPAIRSSIZE (19UL)

const static CyUAB_reg_pair Filter_1_UABH_B_FILTER_initPairs[Filter_1_UABH_B_FILTER_INITPAIRSSIZE] =
{
    /* OA_CTRL default always first element in initPairs */
    /* Topology-invariant registers */
     {Filter_1_UABH_B_OA_CTRL_PTR        , ((uint32)Filter_1_UABH_B_DEFAULT_OA_CTRL)}
    ,{Filter_1_UABH_B_SW_STATIC_PTR      , ((uint32)Filter_1_UABH_B_DEFAULT_SW_STATIC)}
    ,{Filter_1_UABH_B_SW_MODBIT_SRC_PTR  , ((uint32)Filter_1_UABH_B_INVAR_SW_MODBIT_SRC)}
    ,{Filter_1_UABH_B_SRAM_CTRL_PTR      , ((uint32)Filter_1_UABH_B_INVAR_SRAM_CTRL)}
    ,{Filter_1_UABH_B_INTR_MASK_PTR      , ((uint32)Filter_1_UABH_B_DEFAULT_INTR_MASK)}
    ,{Filter_1_UABH_B_SW_BOOST_CTRL_PTR  , ((uint32)Filter_1_UABH_B_DEFAULT_SW_BOOST_CTRL)}
    ,{Filter_1_UABH_B_SW_OTHER_PTR       , ((uint32)Filter_1_UABH_B_DEFAULT_SW_OTHER)}

    #if (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)
        /* Filter-invariant registers */
        ,{Filter_1_UABH_B_SW_CA_IN0_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CA_IN0)}
        ,{Filter_1_UABH_B_SW_CA_IN1_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CA_IN1)}
        ,{Filter_1_UABH_B_SW_CA_TOP_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CA_TOP)}
        ,{Filter_1_UABH_B_SW_CB_IN0_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CB_IN0)}
        ,{Filter_1_UABH_B_SW_CB_IN1_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CB_IN1)}
        ,{Filter_1_UABH_B_SW_CB_TOP_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CB_TOP)}
        ,{Filter_1_UABH_B_SW_CC_IN0_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CC_IN0)}
        ,{Filter_1_UABH_B_SW_CC_IN1_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CC_IN1)}
        ,{Filter_1_UABH_B_SW_CF_BOT_PTR      , ((uint32)Filter_1_UABH_B_LOWQSTAT_SW_CF_BOT)}

        /* Parameter-based registers */
        ,{Filter_1_UABH_B_CAP_CTRL_PTR       , ((uint32)Filter_1_UABH_B_LOWQDYN_CAP_CTRL)}
        ,{Filter_1_UABH_B_SW_CC_TOP_PTR      , ((uint32)Filter_1_UABH_B_LOWQDYN_SW_CC_TOP)}
        ,{Filter_1_UABH_B_CAP_ABCF_VAL_PTR   , ((uint32)Filter_1_UABH_B_LOWQDYN_CAP_ABCF_VAL)}
    #elif (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_HIGH_Q)
        /* Filter-invariant registers */
        ,{Filter_1_UABH_B_SW_CA_IN0_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CA_IN0)}
        ,{Filter_1_UABH_B_SW_CA_IN1_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CA_IN1)}
        ,{Filter_1_UABH_B_SW_CA_TOP_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CA_TOP)}
        ,{Filter_1_UABH_B_SW_CB_IN0_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN0)}
        ,{Filter_1_UABH_B_SW_CB_IN1_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN1)}
        ,{Filter_1_UABH_B_SW_CC_IN0_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN0)}
        ,{Filter_1_UABH_B_SW_CC_IN1_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN1)}
        ,{Filter_1_UABH_B_SW_CF_BOT_PTR      , ((uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CF_BOT)}

        /* Parameter-based registers */
        ,{Filter_1_UABH_B_CAP_CTRL_PTR       , ((uint32)Filter_1_UABH_B_HIGHQDYN_CAP_CTRL)}
        ,{Filter_1_UABH_B_SW_CB_TOP_PTR      , ((uint32)Filter_1_UABH_B_HIGHQDYN_SW_CB_TOP)}
        ,{Filter_1_UABH_B_SW_CC_TOP_PTR      , ((uint32)Filter_1_UABH_B_HIGHQDYN_SW_CC_TOP)}
        ,{Filter_1_UABH_B_CAP_ABCF_VAL_PTR   , ((uint32)Filter_1_UABH_B_HIGHQDYN_CAP_ABCF_VAL)}
    #endif /* (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q) */
};

const static CyUAB_config Filter_1_UABH_A_FILTER_config = {
    Filter_1_UABH_A_waveConfig,
    (CyUAB_reg_pair*) Filter_1_UABH_A_FILTER_initPairs,
    CyUAB_SHARED_SW_CFG(Filter_1_UABH_A_PARAM_REF_TIED,Filter_1_UABH_A_PARAM_AGND_TIED,
        CyUAB_CLK_PHI4, CyUAB_CLK_PHI4, CyUAB_CLK_PHI4),
    Filter_1_UABH_A_NUM_STEPS,
    (uint8)(Filter_1_UABH_A_ELEMENT_COUNT(Filter_1_UABH_A_FILTER_initPairs))
};

const static CyUAB_config Filter_1_UABH_B_FILTER_config = {
    Filter_1_UABH_B_waveConfig,
    (CyUAB_reg_pair*) Filter_1_UABH_B_FILTER_initPairs,
    CyUAB_SHARED_SW_CFG(Filter_1_UABH_B_PARAM_REF_TIED,Filter_1_UABH_B_PARAM_AGND_TIED,
        CyUAB_CLK_PHI4, CyUAB_CLK_PHI4, CyUAB_CLK_PHI4),
    Filter_1_UABH_B_NUM_STEPS,
    (uint8)(Filter_1_UABH_B_ELEMENT_COUNT(Filter_1_UABH_B_FILTER_initPairs))
};


/*******************************************************************************
* Function Name: Filter_1_Start
****************************************************************************//**
*
* \par
* Start the Component.  Must be called before using the Component.
*
* \par
* Invokes Filter_1_Init() (the first time it is called only) and
* Filter_1_Enable().  After this function call, the Component is enabled
* and operating.  This is the preferred method to begin Component operation.
*
* \par
* \b Note This function also calls Filter_1_TrimFilterVos() the first time it is called
* to reduce the filter offset. This requires that the Agnd be applied to the component
* before calling this function the first time. If the Pol/Mod bit is used,
* apply the desired the Pol/Mod level as well before calling Filter_1_Start().
*
*******************************************************************************/
void Filter_1_Start(void)
{
    if (0U == Filter_1_initVar)
    {
        Filter_1_Init();
    }

    Filter_1_Enable();

    if (0U == Filter_1_initVar)
    {
        Filter_1_TrimFilterVos();
        Filter_1_initVar = 1U;
    }
}


/*******************************************************************************
* Function Name: Filter_1_Init
****************************************************************************//**
*
* \par
* Initialize the Component according to parameters defined in the
* customizer.
*
* \par
* It is not necessary to call Filter_1_Init() because the
* Filter_1_Start() API calls this function and is the preferred
* method to begin the Component operation.
*
*******************************************************************************/
void Filter_1_Init(void)
{
    /* Initialize each UAB half. */
    Filter_1_UABH_A_Init(&Filter_1_UABH_A_FILTER_config);
    Filter_1_UABH_B_Init(&Filter_1_UABH_B_FILTER_config);

    /* Route the CTB output to the negative input so CTB acts as a buffer. */
    Filter_1_AMux_Select(0U);

    /* Initialize the output CTB buffer. */
    Filter_1_CTB_CTRL_REG = Filter_1_CTB_CTRL_ENABLED;
    Filter_1_OA_RES_CTRL_REG = Filter_1_OA_DRIVE_STR_SEL_10X | Filter_1_OA_HYST_EN |  Filter_1_OA_DSI_LEVEL;
    Filter_1_OA_COMP_TRIM_REG = Filter_1_OA_COMP_TRIM_VALUE;
    
}


/*******************************************************************************
* Function Name: Filter_1_Enable
****************************************************************************//**
*
* \par
* Enable the Component.
*
* \par
* It is not necessary to call Filter_1_Enable() because the
* Filter_1_Start() API calls this function and is the preferred
* method to begin the Component operation.
*
*******************************************************************************/
void Filter_1_Enable(void)
{
    /* Turn on the power for the UAB block. The enable bit is shared for both halves. */
    Filter_1_UABH_A_Enable();

    /* Begin clocking to each UAB half. */
    Filter_1_UABH_A_Run(1UL);
    Filter_1_UABH_B_Run(1UL);

    CyDelayUs(Filter_1_STARTUP_DELAY);

    /* Enable the output CTB buffer. */
    Filter_1_OA_RES_CTRL_REG |= (Filter_1_OA_PWR_MODE_HIGH | Filter_1_OA_PUMP_EN);
}


/*******************************************************************************
* Function Name: Filter_1_Stop
****************************************************************************//**
*
* \par
* Stop the Component.
*
* \par
* Power down the UAB and output buffer blocks.
*
*******************************************************************************/
void Filter_1_Stop(void)
{
    /* Turn off the power to the output CTB buffer. */
    Filter_1_OA_RES_CTRL_REG &= ~(Filter_1_OA_PWR_MODE_MASK | Filter_1_OA_PUMP_EN);

    /* Calling the UAB Stop() turns off the clocking. */
    Filter_1_UABH_A_Stop();
    Filter_1_UABH_B_Stop();

    /* Turn off the power to the entire UAB block. The enable bit for both halves are shared. */
    Filter_1_UABH_A_UAB_CTRL_REG &= ~Filter_1_UABH_A_ENABLED_MASK;

}


/*******************************************************************************
* Function Name: Filter_1_ClearInterrupt
****************************************************************************//**
*
* \par
* Clear the comparator interrupt so that subsequent interrupts
* can be triggered and handled.
*
*******************************************************************************/
void Filter_1_ClearInterrupt(void)
{
    Filter_1_UABH_B_ClearInterrupt(CyUAB_INTR_COMP);
}


/*******************************************************************************
* Function Name: Filter_1_GetInterruptStatus
****************************************************************************//**
*
* \par
* Return the comparator interrupt status.
*
* \par
* \b Returns
* - 0: Comparator did not trigger
* - 1: Comparator interrupt triggered
*
*******************************************************************************/
uint32 Filter_1_GetInterruptStatus(void)
{
    return Filter_1_UABH_B_GetInterruptIsMasked(CyUAB_INTR_COMP);
}


/*******************************************************************************
* Function Name: Filter_1_GetCompStatus
****************************************************************************//**
*
* \par
* Return the comparator output status.
*
* \par
* \b Returns
* - 0: Comparator output is low
* - 1: Comparator output is high
*
*******************************************************************************/
uint32 Filter_1_GetCompStatus(void)
{
    return Filter_1_UABH_B_GetCompStatus();
}


/*******************************************************************************
* Function Name: Filter_1_TrimFilterVos
****************************************************************************//**
*
* \par
* Run an algorithm to reduce voltage offset using the UAB's Agnd buffer
* and Opamp trim.
*
* \par
* During trimming, the filter inputs are disconnected from the UAB block,
* the non-inverting input of both UAB opamps are connected to Agnd,
* and the output buffer is configured as a comparator.
*
* \par
* Trimming is done by comparing the filter output with Agnd.
* The algorithm steps through the Opamp trim codes first and then the
* Agnd trim codes to find where the filter output crosses Agnd.
* For each trim code, a blocking delay is used to allow the filter output
* to settle before reading the comparator status. This delay is equivalent
* to 9&tau;, where tau is the filter time constant:
*
* \f[
*   \tau = \frac{1}{2 \times \pi \times F}
* \f]
*
* \par
* For Band pass and Band stop, F is the bandwidth.
* For Low pass and High pass, F is the corner frequency.
* The algorithm can check up to 40 different trim codes, but it will typically
* complete in much less time.
*
* \par
* Once trimming is complete, the UAB and output buffer are restored to
* their original configuration.
*
* \par
* \b Note Agnd must be applied to the component before calling this function.
* If the Pol/Mod bit is used, set the Pol/Mod level to the desired value
* before calling this function.
*
*******************************************************************************/
void Filter_1_TrimFilterVos(void)
{
    uint32 opampTrim = 0UL;
    uint32 agndTrim = 0UL;
    uint32 compStatus = 0UL;
    uint32 direction = 0UL;

    Filter_1_SetupComparatorTrim();

    /* Sweep from center to crossing */
    compStatus = Filter_1_SetOpampAndAgndTrim(Filter_1_OPAMP_TRIM_POS_BASE, Filter_1_AGND_TRIM_POS_BASE);
    if (0UL == compStatus)
    {
        opampTrim = Filter_1_RaiseOpampTrimToCrossing(Filter_1_IncOpampTrim(Filter_1_OPAMP_TRIM_POS_BASE));

        direction = Filter_1_FindAgndTrimDirection();
        if (0UL != direction)
        {
            agndTrim = Filter_1_RaiseAgndTrimToCrossing(Filter_1_IncAgndTrim(Filter_1_AGND_TRIM_POS_BASE));
            if ((agndTrim == (Filter_1_AGND_TRIM_POS_LIMIT - 1UL))
                && (opampTrim != (Filter_1_OPAMP_TRIM_POS_LIMIT - 1UL)))
            {
                opampTrim = Filter_1_IncOpampTrim(opampTrim);
                (void) Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
                (void) Filter_1_LowerAgndTrimToCrossing(Filter_1_AGND_TRIM_POS_BASE);
            }
        }
        else
        {
            agndTrim = Filter_1_LowerAgndTrimToCrossing(Filter_1_DecAgndTrim(Filter_1_AGND_TRIM_POS_BASE));
            if ((agndTrim == (Filter_1_AGND_TRIM_NEG_LIMIT - 1UL))
                && (opampTrim != (Filter_1_OPAMP_TRIM_POS_LIMIT - 1UL)))
            {
                opampTrim = Filter_1_IncOpampTrim(opampTrim);
                (void) Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
                (void) Filter_1_RaiseAgndTrimToCrossing(Filter_1_AGND_TRIM_POS_BASE);
            }
        }

    }
    else
    {
        opampTrim = Filter_1_LowerOpampTrimToCrossing(Filter_1_DecOpampTrim(Filter_1_OPAMP_TRIM_POS_BASE));

        direction = Filter_1_FindAgndTrimDirection();
        if (0UL != direction)
        {
            agndTrim = Filter_1_LowerAgndTrimToCrossing(Filter_1_DecAgndTrim(Filter_1_AGND_TRIM_POS_BASE));

            if ((agndTrim == (Filter_1_AGND_TRIM_NEG_LIMIT - 1UL))
                && (opampTrim != (Filter_1_OPAMP_TRIM_NEG_LIMIT - 1UL)))
            {
                opampTrim = Filter_1_DecOpampTrim(opampTrim);
                (void) Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
                (void) Filter_1_RaiseAgndTrimToCrossing(Filter_1_AGND_TRIM_POS_BASE);
            }
        }
        else
        {
            agndTrim = Filter_1_RaiseAgndTrimToCrossing(Filter_1_IncAgndTrim(Filter_1_AGND_TRIM_POS_BASE));

            if ((agndTrim == (Filter_1_AGND_TRIM_POS_LIMIT - 1UL))
                && (opampTrim != (Filter_1_OPAMP_TRIM_NEG_LIMIT - 1UL)))
            {
                opampTrim = Filter_1_DecOpampTrim(opampTrim);
                (void) Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
                (void) Filter_1_LowerAgndTrimToCrossing(Filter_1_AGND_TRIM_POS_BASE);
            }
        }

    }

    Filter_1_UndoComparatorTrimSetup();
}


/*******************************************************************************
* Function Name: Filter_1_SetupComparatorTrim
********************************************************************************
*
* Make proper connections to being trimming the Agnd buffer
* and Opamp offset.
*
*******************************************************************************/
static void Filter_1_SetupComparatorTrim(void)
{
    uint32 readModWrite = 0uL;
    
    /* Disconnect all input sources from UAB and connect Vminus to Agnd */
    #if (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)
        /* Open B00 and clock B0R (input to reference buffer) */
        Filter_1_UABH_A_SW_CB_IN0_REG = (uint32)(CyUAB_CLK_PHI4 << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT));
        readModWrite = Filter_1_UABH_A_SW_CB_IN1_REG & ~Filter_1_UABH_A_SW_BR_MODBIT_MASK;
        Filter_1_UABH_A_SW_CB_IN1_REG = readModWrite | (uint32)(CyUAB_CLK_PHI10 << CyUAB_SW_BR_MODBIT_SHIFT);

        #if (0 == Filter_1_MODBIT_ENABLED)
            /* Open C10 and close C1R (input to reference buffer) */
            Filter_1_UABH_B_SW_CC_IN0_REG = (uint32)(CyUAB_CLK_PHI4 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT));
            readModWrite = Filter_1_UABH_B_SW_CC_IN1_REG & ~(uint32)Filter_1_UABH_B_SW_CR_MODBIT_MASK;
            Filter_1_UABH_B_SW_CC_IN1_REG = readModWrite | (uint32)(CyUAB_CLK_PHI5 << CyUAB_SW_CR_MODBIT_SHIFT);
        #endif /* (0 == Filter_1_MODBIT_ENABLED) */
    #else
        /* Open B10*/
        Filter_1_UABH_B_SW_CB_IN0_REG = (uint32)(CyUAB_CLK_PHI4 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT));
        
        #if (0 == Filter_1_MODBIT_ENABLED)
            /* Open C00 and close C0R and B1R (input to reference buf) */
            Filter_1_UABH_A_SW_CC_IN0_REG = (uint32)(CyUAB_CLK_PHI4 << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT));
            readModWrite = Filter_1_UABH_A_SW_CC_IN1_REG & ~Filter_1_UABH_A_SW_CR_MODBIT_MASK;
            Filter_1_UABH_A_SW_CC_IN1_REG = readModWrite | (uint32)(CyUAB_CLK_PHI5 << CyUAB_SW_CR_MODBIT_SHIFT);
            readModWrite = Filter_1_UABH_B_SW_CB_IN1_REG & ~Filter_1_UABH_B_SW_BR_MODBIT_MASK;
            Filter_1_UABH_B_SW_CB_IN1_REG = readModWrite | (uint32)(CyUAB_CLK_PHI5 << CyUAB_SW_BR_MODBIT_SHIFT);
        #else
            readModWrite = Filter_1_UABH_B_SW_CB_IN1_REG & ~Filter_1_UABH_B_SW_BR_MODBIT_MASK;
            Filter_1_UABH_B_SW_CB_IN1_REG = readModWrite | (uint32)(CyUAB_CLK_PHI10 << CyUAB_SW_BR_MODBIT_SHIFT);
        #endif /* (0 == Filter_1_MODBIT_ENABLED) */
        
        #if (Filter_1_FILTER_GT_C1_NUMERATOR_VAL > 0UL)
            /* Open C10 and close C1G */
            Filter_1_UABH_B_SW_CC_IN0_REG = (uint32)(CyUAB_CLK_PHI4 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT));
            Filter_1_UABH_B_SW_CC_IN1_REG |= (uint32)(CyUAB_CLK_PHI10 << CyUAB_SW_CR_MODBIT_SHIFT);
        #endif /* (Filter_1_FILTER_GT_C1_NUMERATOR_VAL > 0UL) */
    #endif /* (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q) */

    /* Power on the UAB half A reference buffer. */
    Filter_1_UABH_A_OA_CTRL_REG |= (uint32) Filter_1_UABH_A_REF_PWR_MASK;
    
    /* Connect the analog reference to the negative input of the CTB. */
    Filter_1_AMux_Select(1U);
    
    /* Enable the comparator mode of the CTB. */
    Filter_1_OA_RES_CTRL_REG |= Filter_1_OA_COMP_EN;

}

/*******************************************************************************
* Function Name: Filter_1_UndoComparatorTrimSetup
********************************************************************************
*
* Undo all changes made in Filter_1_SetupComparatorTrim()
* to bring the Component back to normal operation.
*
*******************************************************************************/
static void Filter_1_UndoComparatorTrimSetup(void)
{
    /* Disable the comparator mode of the CTB. */
    Filter_1_OA_RES_CTRL_REG &= ~Filter_1_OA_COMP_EN;

    /* Disconnect the analog reference from the negative input of the CTB. */
    Filter_1_AMux_Select(0U);
    
    /* Power off the UAB half A reference buffer. */
    Filter_1_UABH_A_OA_CTRL_REG &= ~(uint32) Filter_1_UABH_A_REF_PWR_MASK;
 
    /* Reset controls for switches */
    #if (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)
        /* Reset B00 and B0G */
        Filter_1_UABH_A_SW_CB_IN0_REG = (uint32)Filter_1_UABH_A_LOWQDYN_SW_CB_IN0;
        Filter_1_UABH_A_SW_CB_IN1_REG = (uint32)Filter_1_UABH_A_LOWQDYN_SW_CB_IN1;
        /* Reset C10 and C1G */
        Filter_1_UABH_B_SW_CC_IN0_REG = (uint32)Filter_1_UABH_B_LOWQSTAT_SW_CC_IN0;
        Filter_1_UABH_B_SW_CC_IN1_REG = (uint32)Filter_1_UABH_B_LOWQSTAT_SW_CC_IN1;
    #else
        /* Reset C00 and C0G */
        Filter_1_UABH_A_SW_CC_IN0_REG = (uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN0;
        Filter_1_UABH_A_SW_CC_IN1_REG = (uint32)Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN1;
        /* Reset C10 and C1G */
        Filter_1_UABH_B_SW_CC_IN0_REG = (uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN0;
        Filter_1_UABH_B_SW_CC_IN1_REG = (uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN1;
        /* Reset B10 and B1G */
        Filter_1_UABH_B_SW_CB_IN0_REG = (uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN0;
        Filter_1_UABH_B_SW_CB_IN1_REG = (uint32)Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN1;
    #endif /* (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q) */
}

/*******************************************************************************
* Function Name: Filter_1_FindAgndTrimDirection
********************************************************************************
*
* Find if offset increases or decreases with Agnd code.
*
* If comparator status is high at the highest Agnd trim,
* then offset increases with Agnd code. Call this function
* with an Opamp trim that contains a zero crossing.
*
*******************************************************************************/
static uint32 Filter_1_FindAgndTrimDirection(void)
{
    return Filter_1_SetAgndTrim(Filter_1_AGND_TRIM_POS_LIMIT - 1UL);
}

/*******************************************************************************
* Function Name: Filter_1_RaiseOpampTrimToCrossing
********************************************************************************
*
* Step through the Opamp trim codes in increasing order
* to find the point where the offset crosses Agnd.
*
*******************************************************************************/
static uint32 Filter_1_RaiseOpampTrimToCrossing(uint32 startTrim)
{
    uint32 opampTrim;
    uint32 lastOpampTrim;
    uint32 compStatus;

    lastOpampTrim = Filter_1_DecOpampTrim(startTrim);
    for (opampTrim = startTrim;
        opampTrim != Filter_1_OPAMP_TRIM_NEG_LIMIT;
        opampTrim = Filter_1_IncOpampTrim(opampTrim))
    {
        compStatus = Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
        if (0UL != compStatus)
        {
            (void) Filter_1_SetOpampTrim(lastOpampTrim);
            break;
        }
        lastOpampTrim = opampTrim;
    }

    return lastOpampTrim;
}


/*******************************************************************************
* Function Name: Filter_1_LowerOpampTrimToCrossing
********************************************************************************
*
* Step through the Opamp trim codes in decreasing order
* to find the point where the offset crosses Agnd.
*
*******************************************************************************/
static uint32 Filter_1_LowerOpampTrimToCrossing(uint32 startTrim)
{
    uint32 opampTrim;
    uint32 lastOpampTrim;
    uint32 compStatus;

    lastOpampTrim = Filter_1_IncOpampTrim(startTrim);
    for (opampTrim = startTrim;
        opampTrim != Filter_1_OPAMP_TRIM_NEG_LIMIT;
        opampTrim = Filter_1_DecOpampTrim(opampTrim))
    {
        compStatus = Filter_1_SetOpampAndAgndTrim(opampTrim, Filter_1_AGND_TRIM_POS_BASE);
        if (0UL == compStatus)
        {
            (void) Filter_1_SetOpampTrim(lastOpampTrim);
            break;
        }
        lastOpampTrim = opampTrim;
    }

    return lastOpampTrim;
}


/*******************************************************************************
* Function Name: Filter_1_RaiseAgndTrimToCrossing
********************************************************************************
*
* Step through the Agnd trim codes in increasing order
* to find the point where the offset crosses Agnd.
*
*******************************************************************************/
static uint32 Filter_1_RaiseAgndTrimToCrossing(uint32 startTrim)
{
    uint32 agndTrim;
    uint32 lastAgndTrim;
    uint32 compStatus;

    lastAgndTrim = Filter_1_DecAgndTrim(startTrim);
    for (agndTrim = startTrim;
        agndTrim != Filter_1_AGND_TRIM_NEG_LIMIT;
        agndTrim = Filter_1_IncAgndTrim(agndTrim))
    {
        compStatus = Filter_1_SetAgndTrim(agndTrim);
        if (0UL != compStatus)
        {
            (void) Filter_1_SetAgndTrim(lastAgndTrim);
            break;
        }
        lastAgndTrim = agndTrim;
    }

    return lastAgndTrim;
}


/*******************************************************************************
* Function Name: Filter_1_LowerAgndTrimToCrossing
********************************************************************************
*
* Step through the Agnd trim codes in decreasing order
* to find the point where the offset crosses Agnd.
*
*******************************************************************************/
static uint32 Filter_1_LowerAgndTrimToCrossing(uint32 startTrim)
{
    uint32 agndTrim = startTrim;
    uint32 lastAgndTrim = agndTrim;
    uint32 compStatus = 1UL;

    lastAgndTrim = Filter_1_IncAgndTrim(startTrim);
    for (agndTrim = startTrim;
        agndTrim != Filter_1_AGND_TRIM_NEG_LIMIT;
        agndTrim = Filter_1_DecAgndTrim(agndTrim))
    {
        compStatus = Filter_1_SetAgndTrim(agndTrim);
        if (0UL == compStatus)
        {
            (void) Filter_1_SetAgndTrim(lastAgndTrim);
            break;
        }
        lastAgndTrim = agndTrim;
    }

    return lastAgndTrim;
}


/*******************************************************************************
* Function Name: Filter_1_SetOpampAndAgndTrim
********************************************************************************
*
* Write the Agnd and Opamp trim codes and return the comparator status.
*
*******************************************************************************/
static uint32 Filter_1_SetOpampAndAgndTrim(uint32 opampTrim, uint32 agndTrim)
{
    uint32 compStatus = 0UL;

    uint32 trimRegVal = Filter_1_UABH_A_OA_TRIM_OA_REG;
    trimRegVal &= ~(Filter_1_OPAMP_TRIM_MASK << CyUAB_OA_OFFSET_SHIFT);
    trimRegVal |= (opampTrim << CyUAB_OA_OFFSET_SHIFT);
    Filter_1_UABH_A_OA_TRIM_OA_REG = trimRegVal;

    trimRegVal = Filter_1_UABH_A_OA_TRIM_AGND_REG;
    trimRegVal &= ~(Filter_1_AGND_TRIM_MASK << CyUAB_AGND_OFFSET_SHIFT);
    trimRegVal |= (agndTrim << CyUAB_AGND_OFFSET_SHIFT);
    Filter_1_UABH_A_OA_TRIM_AGND_REG = trimRegVal;

    /* Allow circuit to settle before reading comparator status. */
    CyDelayUs(Filter_1_TRIM_DELAY);

    compStatus = Filter_1_COMP_STAT_REG & Filter_1_COMP_MASK;
    return compStatus;
}


/*******************************************************************************
* Function Name: Filter_1_SetOpampTrim
********************************************************************************
*
* Write the Opamp trim code and return the comparator status.
*
*******************************************************************************/
static uint32 Filter_1_SetOpampTrim(uint32 opampTrim)
{
    uint32 compStatus = 0UL;

    uint32 trimRegVal = Filter_1_UABH_A_OA_TRIM_OA_REG;
    trimRegVal &= ~(Filter_1_OPAMP_TRIM_MASK << CyUAB_OA_OFFSET_SHIFT);
    trimRegVal |= (opampTrim << CyUAB_OA_OFFSET_SHIFT);
    Filter_1_UABH_A_OA_TRIM_OA_REG = trimRegVal;

    /* Allow circuit to settle before reading comparator status. */
    CyDelayUs(Filter_1_TRIM_DELAY);

    compStatus = Filter_1_COMP_STAT_REG & Filter_1_COMP_MASK;
    return compStatus;
}


/*******************************************************************************
* Function Name: Filter_1_SetAgndTrim
********************************************************************************
*
* Write the Agnd trim code and return the comparator status.
*
*******************************************************************************/
static uint32 Filter_1_SetAgndTrim(uint32 agndTrim)
{
    uint32 compStatus = 0UL;

    uint32 trimRegVal = Filter_1_UABH_A_OA_TRIM_AGND_REG;
    trimRegVal &= ~(Filter_1_AGND_TRIM_MASK << CyUAB_AGND_OFFSET_SHIFT);
    trimRegVal |= (agndTrim << CyUAB_AGND_OFFSET_SHIFT);
    Filter_1_UABH_A_OA_TRIM_AGND_REG = trimRegVal;

    /* Allow circuit to settle before reading comparator status. */
    CyDelayUs(Filter_1_TRIM_DELAY);

    compStatus = Filter_1_COMP_STAT_REG & Filter_1_COMP_MASK;
    return compStatus;
}


/*******************************************************************************
* Function Name: Filter_1_IncOpampTrim
********************************************************************************
*
* Increments the Opamp trim code by one. Note that Opamp trim code is
* a 4-bit sign-magnitude value.
*
* Skips OPAMP_TRIM_NEG_BASE because it is the same as POS_BASE.
*
*******************************************************************************/
static uint32 Filter_1_IncOpampTrim(uint32 trim)
{

    if (trim < (Filter_1_OPAMP_TRIM_POS_LIMIT - 1UL))
    {
        trim++;
    }
    else if ((Filter_1_OPAMP_TRIM_POS_LIMIT - 1UL) == trim)
    {
        trim = Filter_1_OPAMP_TRIM_NEG_LIMIT;
    }
    else if (trim <= (Filter_1_OPAMP_TRIM_NEG_BASE + 1UL))
    {
        trim = Filter_1_OPAMP_TRIM_POS_BASE;
    }
    else
    {
        trim--;
    }

    return trim;
}


/*******************************************************************************
* Function Name: Filter_1_DecOpampTrim
********************************************************************************
*
* Decrements the Opamp trim code by one. Note that Opamp trim code is
* a 4-bit sign-magnitude value.
*
* Skips OPAMP_TRIM_NEG_BASE because it is the same as POS_BASE.
*
*******************************************************************************/
static uint32 Filter_1_DecOpampTrim(uint32 trim)
{

    if (Filter_1_OPAMP_TRIM_POS_BASE == trim)
    {
        trim = Filter_1_OPAMP_TRIM_NEG_BASE + 1UL;
    }
    else if (trim < Filter_1_OPAMP_TRIM_POS_LIMIT)
    {
        trim--;
    }
    else if (trim < Filter_1_OPAMP_TRIM_NEG_LIMIT)
    {
        trim++;
    }
    else
    {
        trim = Filter_1_OPAMP_TRIM_POS_LIMIT - 1UL;
    }

    return trim;
}


/*******************************************************************************
* Function Name: Filter_1_IncAgndTrim
********************************************************************************
*
* Increments the Agnd trim code by one. Note that Agnd trim code is
* a 5-bit sign-magnitude value.
*
* Skips AGND_TRIM_NEG_BASE because it is the same as POS_BASE.
*
*******************************************************************************/
static uint32 Filter_1_IncAgndTrim(uint32 trim)
{

    if (trim < (Filter_1_AGND_TRIM_POS_LIMIT - 1UL))
    {
        trim++;
    }
    else if ((Filter_1_AGND_TRIM_POS_LIMIT - 1UL) == trim)
    {
        trim = Filter_1_AGND_TRIM_NEG_LIMIT;
    }
    else if (trim <= (Filter_1_AGND_TRIM_NEG_BASE + 1UL))
    {
        trim = Filter_1_AGND_TRIM_POS_BASE;
    }
    else
    {
        trim--;
    }

    return trim;
}


/*******************************************************************************
* Function Name: Filter_1_DecAgndTrim
********************************************************************************
*
* Decrements the Agnd trim code by one. Note that Agnd trim code is
* a 5-bit sign-magnitude value.
*
* Skips AGND_TRIM_NEG_BASE because it is the same as POS_BASE.
*
*******************************************************************************/
static uint32 Filter_1_DecAgndTrim(uint32 trim)
{

    if (trim == Filter_1_AGND_TRIM_POS_BASE)
    {
        trim = Filter_1_AGND_TRIM_NEG_BASE + 1UL;
    }
    else if (trim < Filter_1_AGND_TRIM_POS_LIMIT)
    {
        trim--;
    }
    else if (trim < Filter_1_AGND_TRIM_NEG_LIMIT)
    {
        trim++;
    }
    else
    {
        trim = Filter_1_AGND_TRIM_POS_LIMIT - 1UL;
    }

    return trim;
}


/* [] END OF FILE */
