/***************************************************************************//**
* \file     Filter_1.h
* \version  1.10
*
* \brief
* Provides defines to the API for the Filter_1 Component.
*
********************************************************************************
* \copyright
* (c) 2018, Cypress Semiconductor Corporation. All rights reserved.
* This software, including source code, documentation and related
* materials ("Software"), is owned by Cypress Semiconductor
* Corporation ("Cypress") and is protected by and subject to worldwide
* patent protection (United States and foreign), United States copyright
* laws and international treaty provisions. Therefore, you may use this
* Software only as provided in the license agreement accompanying the
* software package from which you obtained this Software ("EULA").
* If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
* non-transferable license to copy, modify, and compile the
* Software source code solely for use in connection with Cypress's
* integrated circuit products. Any reproduction, modification, translation,
* compilation, or representation of this Software except as specified
* above is prohibited without the express written permission of Cypress.
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO
* WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING,
* BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE. Cypress reserves the right to make
* changes to the Software without notice. Cypress does not assume any
* liability arising out of the application or use of the Software or any
* product or circuit described in the Software. Cypress does not
* authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer
* of such system or application assumes all risk of such use and in doing
* so agrees to indemnify Cypress against all liability.
*******************************************************************************/

#if !defined(CY_Filter_1_FILTER_H)
    #define CY_Filter_1_FILTER_H

#include "cyfitter.h"

#include "Filter_1_UABH_A_CyUAB_types.h"
#include "Filter_1_UABH_A_CyUAB_regs.h"
#include "Filter_1_UABH_A_CyUAB.h"
#include "Filter_1_UABH_A_param.h"
#include "Filter_1_UABH_B_param.h"
#include "Filter_1_UABH_A_regs.h"
#include "Filter_1_UABH_B_regs.h"
#include "Filter_1_UABH_A.h"
#include "Filter_1_UABH_B.h"
#include "Filter_1_AMux.h"
#include "Filter_1_intUabClock.h"


/***************************************
*    Variables with External Linkage
***************************************/

/**
* \addtogroup group_globals
* \{
*/

/** Tracks whether block is initialized (1) or not (0). */
extern uint8 Filter_1_initVar;

/** \} globals */


/***************************************
* Function Prototypes
***************************************/

/**
* \addtogroup group_general
* \{
*/
void Filter_1_Start(void);
void Filter_1_Stop(void);
void Filter_1_ClearInterrupt(void);
uint32 Filter_1_GetInterruptStatus(void);
uint32 Filter_1_GetCompStatus(void);

void Filter_1_Init(void);
void Filter_1_Enable(void);

void Filter_1_TrimFilterVos(void);
/** \} general */

/**
* \addtogroup group_power
* \{
*/
void Filter_1_Sleep(void);
void Filter_1_Wakeup(void);
/** \} power */


/***************************************
* Filter parameter constants
***************************************/

#define Filter_1_FILTER_TOPOLOGY_HIGH_Q      (0UL)
#define Filter_1_FILTER_TOPOLOGY_LOW_Q       (1UL)

#define Filter_1_FILTER_TYPE_LOW_PASS        (0UL)
#define Filter_1_FILTER_TYPE_HIGH_PASS       (1UL)
#define Filter_1_FILTER_TYPE_BAND_PASS       (2UL)
#define Filter_1_FILTER_TYPE_BAND_STOP       (3UL)


/***************************************
* Customizer selections
***************************************/

#define Filter_1_FILTER_TYPE                Filter_1_FILTER_TYPE_LOW_PASS
#define Filter_1_FILTER_TOPOLOGY_USED       Filter_1_FILTER_TOPOLOGY_LOW_Q
#define Filter_1_MODBIT_ENABLED             (1)
#define Filter_1_STARTUP_DELAY              (96U)
#define Filter_1_TRIM_DELAY                 (716U)

/***************************************
* Realized capacitor values
***************************************/

/* Fractional capacitors have a numerator 1-63 and a denominator of 64.
 * Non-fractional capacitors have a denominator of 1.
 * Unused capacitors have a numerator of 0.
 * CA may have a value 1-127.
 * CB may only have a value 2-64.
 */
#define Filter_1_FILTER_GT_C1_NUMERATOR_VAL     (3UL)
#define Filter_1_FILTER_GT_C1_DENOMINATOR_VAL   (1UL)
#define Filter_1_FILTER_GT_C2_NUMERATOR_VAL     (3UL)
#define Filter_1_FILTER_GT_C2_DENOMINATOR_VAL   (1UL)
#define Filter_1_FILTER_GT_C3_VAL               (4UL)
#define Filter_1_FILTER_GT_C4_VAL               (4UL)
#define Filter_1_FILTER_GT_Cp_VAL               (0UL)
#define Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL    (0UL)
#define Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL  (1UL)
#define Filter_1_FILTER_GT_Cppp_NUMERATOR_VAL   (0UL) /* Cppp is the clocked version of Cpp */
#define Filter_1_FILTER_GT_Cppp_DENOMINATOR_VAL (1UL)
#define Filter_1_FILTER_GT_CA_VAL               (99UL)
#define Filter_1_FILTER_GT_CB_VAL               (54UL)


/***************************************
* Transfer function coefficients
***************************************/

/* Biquad coefficients are for a transfer function of the form:
 *          Num0 + Num1*z**(-1) + Num2*z**(-2)
 * H(z) =  -------------------------------------
 *             1 + Den1*z**(-1) + Den2*z**(-2)
 */
#define Filter_1_FILTER_IDEAL_BIQUAD_NUM0      (0.000609849608787345)
#define Filter_1_FILTER_IDEAL_BIQUAD_NUM1      (0.00121969921757469)
#define Filter_1_FILTER_IDEAL_BIQUAD_NUM2      (0.000609849608787345)
#define Filter_1_FILTER_IDEAL_BIQUAD_DEN1      (-1.92894232273102)
#define Filter_1_FILTER_IDEAL_BIQUAD_DEN2      (0.931381702423096)

#define Filter_1_FILTER_UAB_BIQUAD_NUM0        (0)
#define Filter_1_FILTER_UAB_BIQUAD_NUM1        (0.00208986415882968)
#define Filter_1_FILTER_UAB_BIQUAD_NUM2        (0)
#define Filter_1_FILTER_UAB_BIQUAD_DEN1        (-1.92894461859979)
#define Filter_1_FILTER_UAB_BIQUAD_DEN2        (0.931034482758621)


/***************************************
* SRAM, modbit source, and startup delay configuration macros
***************************************/

#define Filter_1_UABH_A_INVAR_SRAM_CTRL        (3UL << CyUAB_LAST_STEP_SHIFT)
#define Filter_1_UABH_B_INVAR_SRAM_CTRL        ((3UL << CyUAB_LAST_STEP_SHIFT) \
                                                    |   (((uint32)Filter_1_UABH_B_halfuab__TRIG_SEL) << CyUAB_TRIG_SEL_SHIFT) \
                                                    |   (1UL << CyUAB_TRIGGER_EN_SHIFT))
#define Filter_1_FIRMWARE_MODBIT_SRC           (31UL)
#define Filter_1_UABH_A_INVAR_SW_MODBIT_SRC    ((11 << CyUAB_MODBIT0_SRC_SEL_SHIFT) \
                                                    |  (11 << CyUAB_MODBIT1_SRC_SEL_SHIFT))
#define Filter_1_UABH_B_INVAR_SW_MODBIT_SRC    ((11 << CyUAB_MODBIT0_SRC_SEL_SHIFT) \
                                                    |  (11 << CyUAB_MODBIT1_SRC_SEL_SHIFT))


/***************************************
* Constant used for shifting cyfitter selected input (X0, X1, X2, or X3)
***************************************/

#define Filter_1_INPUT_SEL_SHIFT               (2U)


/***************************************
* Bulk selection define
***************************************/

#define Filter_1_BULK_VDDA_MV_THRESHOLD        (2000)


/***************************************
* Capacitor settings and switch control macros
***************************************/

#if (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)
    /*  C1 = Bbranch
     *  C2 = Cbranch
     *  CA = Abranch + Fbranch */
    #define Filter_1_UABH_A_LOWQDYN_CAP_B_VAL    ((0UL < Filter_1_FILTER_GT_C1_NUMERATOR_VAL) \
                                                       ? ((64UL == Filter_1_FILTER_GT_C1_NUMERATOR_VAL) \
                                                         ? (uint32)(1UL << CyUAB_CB_64_SHIFT) \
                                                         : (uint32)(Filter_1_FILTER_GT_C1_NUMERATOR_VAL << CyUAB_CB_VAL_SHIFT)) \
                                                       : ((64UL == Filter_1_FILTER_GT_Cp_VAL) \
                                                         ? (uint32)(1UL << CyUAB_CB_64_SHIFT) \
                                                         : (uint32)(Filter_1_FILTER_GT_Cp_VAL << CyUAB_CB_VAL_SHIFT)))
    #define Filter_1_UABH_A_LOWQDYN_CAP_C_VAL ((uint32)(Filter_1_FILTER_GT_C2_NUMERATOR_VAL << CyUAB_CC_VAL_SHIFT))
    #define Filter_1_UABH_A_LOWQDYN_CAP_F_VAL_PRE (Filter_1_FILTER_GT_CA_VAL/4u)
    #define Filter_1_UABH_A_LOWQDYN_CAP_F_VAL ((uint32)(Filter_1_UABH_A_LOWQDYN_CAP_F_VAL_PRE << CyUAB_CF_VAL_SHIFT))
    #define Filter_1_UABH_A_LOWQDYN_CAP_A_VAL ((uint32)((Filter_1_FILTER_GT_CA_VAL - (2UL * (Filter_1_UABH_A_LOWQDYN_CAP_F_VAL_PRE + 1UL))) << CyUAB_CA_VAL_SHIFT))

    #define Filter_1_UABH_A_LOWQDYN_CAP_ABCF_VAL ((Filter_1_UABH_A_LOWQDYN_CAP_A_VAL) \
                                                       |  (Filter_1_UABH_A_LOWQDYN_CAP_B_VAL) \
                                                       |  (Filter_1_UABH_A_LOWQDYN_CAP_C_VAL) \
                                                       |  (Filter_1_UABH_A_LOWQDYN_CAP_F_VAL))

    /* Ground unused caps of CB0 and CC0 arrays if fractional C1 or C2 caps are used */
    #define Filter_1_UABH_A_LOWQDYN_CAP_CTRL ((((Filter_1_FILTER_GT_C1_NUMERATOR_VAL > 0UL) \
                                                       && (Filter_1_FILTER_GT_C1_DENOMINATOR_VAL > 1UL)) \
                                                        ? (uint32)(1UL << CyUAB_CB_GND_SHIFT) \
                                                        : 0UL) \
                                                     | ((Filter_1_FILTER_GT_C2_DENOMINATOR_VAL > 1UL) \
                                                        ? (uint32)(1UL << CyUAB_CC_GND_SHIFT) \
                                                        : 0UL))

    /* C3  = Bbranch
     * C4  = Abranch
     * Cpp = Cbranch
     * CB  = Fbranch */
    #define Filter_1_UABH_B_LOWQDYN_CAP_ABCF_VAL (((64UL == Filter_1_FILTER_GT_C3_VAL) \
                                                          ? (uint32)(1UL << CyUAB_CB_64_SHIFT) \
                                                          : (uint32)(Filter_1_FILTER_GT_C3_VAL << CyUAB_CB_VAL_SHIFT)) \
                                                   | (uint32)(Filter_1_FILTER_GT_C4_VAL << CyUAB_CA_VAL_SHIFT) \
                                                   | (uint32)(Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL << CyUAB_CC_VAL_SHIFT) \
                                                   | (uint32)((uint32)((Filter_1_FILTER_GT_CB_VAL / 2UL) - 1UL)  << CyUAB_CF_VAL_SHIFT))

    /* Ground unused caps of CC1 array if fractional Cpp cap is used */
    #define Filter_1_UABH_B_LOWQDYN_CAP_CTRL     ((Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL > 1UL) \
                                                        ? (uint32)(1UL << CyUAB_CC_GND_SHIFT) \
                                                        : 0UL)

    /* Switch B00 for Vin00 */
    #define Filter_1_UABH_B_ALL_OPEN_CB_IN0     (uint32)((CyUAB_CLK_PHI4 << CyUAB_SW_B0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BQ_SHIFT))

    #define Filter_1_UABH_A_LOWQDYN_SW_CB_IN0   ((Filter_1_UABH_B_ALL_OPEN_CB_IN0 \
                                                    &   ~((uint32)CyUAB_CLOCK_MASK  << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) \
                                                    |   ((uint32)CyUAB_CLK_PHI10 << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT)))

    #define Filter_1_UABH_A_LOWQDYN_SW_CB_IN1    ((CyUAB_CLK_PHI9 << CyUAB_SW_BG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BB_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BV_MODBIT_SHIFT))   /* Switch B0G */

    #define Filter_1_UABH_A_LOWQDYN_SW_CB_TOP   ((CyUAB_CLK_PHI1 << CyUAB_SW_SB_SHIFT) \
                                                    |   (CyUAB_CLK_PHI2 << CyUAB_SW_GB_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_RB_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_VB_MODBIT_SHIFT) \
                                                    |   (((Filter_1_FILTER_GT_C1_DENOMINATOR_VAL > 1UL) \
                                                        ? CyUAB_CLK_PHI2 \
                                                        : CyUAB_CLK_PHI1) << CyUAB_SW_TB_SHIFT))  /* Switch S0B, G0B, T0B */

    /* C2 branch switches */
    #define Filter_1_UABH_A_LOWQSTAT_SW_CC_IN0 ((CyUAB_CLK_PHI1  << CyUAB_SW_CQ_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT))   /* Switch C0Q */

    #define Filter_1_UABH_A_LOWQSTAT_SW_CC_IN1 ((CyUAB_CLK_PHI2  << CyUAB_SW_CG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CV_MODBIT_SHIFT))   /* Switch C0G */

    #define Filter_1_UABH_A_LOWQDYN_SW_CC_TOP   ((CyUAB_CLK_PHI1 << CyUAB_SW_SC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI2 << CyUAB_SW_GC_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_RC_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_VC_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_ZC_SHIFT) \
                                                    |   (((Filter_1_FILTER_GT_C2_DENOMINATOR_VAL > 1UL) \
                                                        ? CyUAB_CLK_PHI2 \
                                                        : CyUAB_CLK_PHI1) << CyUAB_SW_TC_SHIFT))  /* Switch S0C, G0C, T0C */

    /* Cpp branch switches */
    #define Filter_1_UABH_B_ALL_OPEN_CC_IN0     (uint32)((CyUAB_CLK_PHI4 << CyUAB_SW_C0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CQ_SHIFT))

    #define Filter_1_UABH_B_LOWQSTAT_SW_CC_IN0 ((Filter_1_UABH_B_ALL_OPEN_CC_IN0 \
                                                    &   ~((uint32)CyUAB_CLOCK_MASK  << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) \
                                                    |   ((uint32)CyUAB_CLK_PHI4 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) /* Switch C10 for Vin10 */

    #define Filter_1_UABH_B_LOWQSTAT_SW_CC_IN1 ((CyUAB_CLK_PHI4 << CyUAB_SW_CG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CV_MODBIT_SHIFT))   /* Switch C1G */

    #define Filter_1_UABH_B_LOWQDYN_SW_CC_TOP    ((CyUAB_CLK_PHI4 << CyUAB_SW_SC_SHIFT) \
                                                        | (CyUAB_CLK_PHI4 << CyUAB_SW_RC_MODBIT_SHIFT) \
                                                        | (CyUAB_CLK_PHI4 << CyUAB_SW_GC_MODBIT_SHIFT) \
                                                        | (CyUAB_CLK_PHI4 << CyUAB_SW_VC_MODBIT_SHIFT) \
                                                        | (CyUAB_CLK_PHI4 << CyUAB_SW_ZC_SHIFT) \
                                                        | (((Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL > 1UL) \
                                                        ? CyUAB_CLK_PHI4 \
                                                        : CyUAB_CLK_PHI5) << CyUAB_SW_TC_SHIFT)) /* Switch S1C, G1C, T1C */


    /* CA branch switches */
    #define Filter_1_UABH_A_LOWQSTAT_SW_CA_IN0 ((CyUAB_CLK_PHI5 << CyUAB_SW_AP_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A0_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A1_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A2_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A3_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AQ_SHIFT)) /* Switch A0P */

    #define Filter_1_UABH_A_LOWQSTAT_SW_CA_IN1 ((CyUAB_CLK_PHI4  << CyUAB_SW_AG_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AA_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AR_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AV_MODBIT_SHIFT))

    #define Filter_1_UABH_A_LOWQSTAT_SW_CA_TOP ((CyUAB_CLK_PHI5 << CyUAB_SW_SA_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_RA_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_GA_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_VA_MODBIT_SHIFT)) /* Switch S0A */

    #define Filter_1_UABH_A_LOWQSTAT_SW_CF_BOT ((CyUAB_CLK_PHI5 << CyUAB_SW_PF_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_GF_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_PS_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_PO_SHIFT))    /* Switch P0F */

    /* C4 branch switches */
    #define Filter_1_UABH_B_LOWQSTAT_SW_CA_IN0 ((CyUAB_CLK_PHI2  << CyUAB_SW_AP_SHIFT)  \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A0_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A1_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A2_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_A3_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AQ_SHIFT)) /* Switch A1P */

    #define Filter_1_UABH_B_LOWQSTAT_SW_CA_IN1 ((CyUAB_CLK_PHI1  << CyUAB_SW_AG_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AA_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AR_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AV_MODBIT_SHIFT)) /* Switch A1G */

    #define Filter_1_UABH_B_LOWQSTAT_SW_CA_TOP ((CyUAB_CLK_PHI2  << CyUAB_SW_SA_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_RA_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_VA_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI1  << CyUAB_SW_GA_MODBIT_SHIFT)) /* Switch S1A and G1A */

    /* C3 branch switches */
    #define Filter_1_UABH_B_LOWQSTAT_SW_CB_IN0 ((CyUAB_CLK_PHI1  << CyUAB_SW_BQ_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_B0_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_B1_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_B2_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_B3_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_BP_SHIFT))    /* Switch B1Q */

    #define Filter_1_UABH_B_LOWQSTAT_SW_CB_IN1 ((CyUAB_CLK_PHI2  << CyUAB_SW_BG_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_BB_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_BR_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_BV_MODBIT_SHIFT)) /* Switch B1G */

    #define Filter_1_UABH_B_LOWQSTAT_SW_CB_TOP ((CyUAB_CLK_PHI2 << CyUAB_SW_SB_SHIFT) \
                                                  | (CyUAB_CLK_PHI1  << CyUAB_SW_GB_MODBIT_SHIFT) \
                                                  | (CyUAB_CLK_PHI4  << CyUAB_SW_RB_MODBIT_SHIFT) \
                                                  | (CyUAB_CLK_PHI4  << CyUAB_SW_VB_MODBIT_SHIFT) \
                                                  | (CyUAB_CLK_PHI5 << CyUAB_SW_TB_SHIFT))  /* Switch S1B, G1B, T1B */

    /* CB branch and output switches */
    #define Filter_1_UABH_B_LOWQSTAT_SW_CF_BOT ((CyUAB_CLK_PHI5 << CyUAB_SW_PF_SHIFT) \
                                                  | (CyUAB_CLK_PHI4  << CyUAB_SW_GF_SHIFT) \
                                                  | (CyUAB_CLK_PHI4  << CyUAB_SW_PS_SHIFT) \
                                                  | (CyUAB_CLK_PHI3  << CyUAB_SW_PO_SHIFT)) /* Switch Q1F, Q10 */

#elif (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_HIGH_Q)
    /*  C4 = Abranch
     *  C2 = Bbranch
     *  Cp = Cbranch
     *  CA = Fbranch */
    #define Filter_1_UABH_A_HIGHQDYN_CAP_ABCF_VAL (((64UL == Filter_1_FILTER_GT_C2_NUMERATOR_VAL) \
                                                          ? (1UL << CyUAB_CB_64_SHIFT) \
                                                          : (Filter_1_FILTER_GT_C2_NUMERATOR_VAL << CyUAB_CB_VAL_SHIFT)) \
                                                        | (Filter_1_FILTER_GT_Cp_VAL << CyUAB_CC_VAL_SHIFT)           \
                                                        | (Filter_1_FILTER_GT_C4_VAL << CyUAB_CA_VAL_SHIFT)           \
                                                        | ((uint32)((Filter_1_FILTER_GT_CA_VAL / 2U) - 1UL) << CyUAB_CF_VAL_SHIFT))

    /* Ground unused caps of CB0 array if fractional C1 cap is used */
    #define Filter_1_UABH_A_HIGHQDYN_CAP_CTRL ((1UL < Filter_1_FILTER_GT_C2_DENOMINATOR_VAL) \
                                                        ? (1UL << CyUAB_CB_GND_SHIFT)     \
                                                        : 0UL )

    /* C3  = Abranch
     * Cpp (static) or Cppp (clocked) = Bbranch
     * C1  = Cbranch
     * CB  = Fbranch */
    #define Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL_PRE    ((Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL == 0UL) \
                                                                ? Filter_1_FILTER_GT_Cppp_NUMERATOR_VAL \
                                                                : Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL)
    #define Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL_PRE  ((Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL == 0UL) \
                                                                ? Filter_1_FILTER_GT_Cppp_DENOMINATOR_VAL \
                                                                : Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL)

    #define Filter_1_UABH_B_HIGHQDYN_CAP_ABCF_VAL (((64UL == Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL_PRE) \
                                                          ? (1UL << CyUAB_CB_64_SHIFT) \
                                                          : (Filter_1_FILTER_GT_Cpp_NUMERATOR_VAL_PRE << CyUAB_CB_VAL_SHIFT)) \
                                                   | (Filter_1_FILTER_GT_C3_VAL << CyUAB_CA_VAL_SHIFT) \
                                                   | (Filter_1_FILTER_GT_C1_NUMERATOR_VAL << CyUAB_CC_VAL_SHIFT) \
                                                   | ((uint32)((Filter_1_FILTER_GT_CB_VAL / 2U) - 1UL) << CyUAB_CF_VAL_SHIFT))

    /* Ground unused caps of CC1 and CB1 arrays if fractional Cpp and C1 caps are used */
    #define Filter_1_UABH_B_HIGHQDYN_CAP_CTRL (((1UL < Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL_PRE) \
                                                        ? (1UL << CyUAB_CB_GND_SHIFT) \
                                                        : 0UL) \
                                                    | ((1UL < Filter_1_FILTER_GT_C1_DENOMINATOR_VAL) \
                                                        ? (1UL << CyUAB_CC_GND_SHIFT) \
                                                        : 0UL))

    /* C2 branch switches */
    #define Filter_1_UABH_A_HIGHQSTAT_SW_CB_IN0 ((CyUAB_CLK_PHI1 << CyUAB_SW_BQ_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B3_MODBIT_SHIFT)) /* Switch B0Q clocked, all others open*/

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CB_IN1 ((CyUAB_CLK_PHI2 << CyUAB_SW_BG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BB_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BV_MODBIT_SHIFT)) /* Switch B0G clocked, all others open*/

    #define Filter_1_UABH_A_HIGHQDYN_SW_CB_TOP ((CyUAB_CLK_PHI1 << CyUAB_SW_SB_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_RB_MODBIT_SHIFT)  \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_VB_MODBIT_SHIFT)  \
                                                    |  (CyUAB_CLK_PHI2 << CyUAB_SW_GB_MODBIT_SHIFT)  \
                                                    |  ((1UL < Filter_1_FILTER_GT_C2_DENOMINATOR_VAL) \
                                                        ? (CyUAB_CLK_PHI2 << CyUAB_SW_TB_SHIFT) \
                                                        : (CyUAB_CLK_PHI5 << CyUAB_SW_TB_SHIFT)))  /* Switch S0B, G0B, ToB */

    /* C4 branch switches */
    #define Filter_1_UABH_A_HIGHQSTAT_SW_CA_IN0 ((CyUAB_CLK_PHI5 << CyUAB_SW_AQ_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_A0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_A1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_A2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_A3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_AP_SHIFT))     /* Switch A0Q */

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CA_IN1 ((CyUAB_CLK_PHI4  << CyUAB_SW_AG_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AA_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AR_MODBIT_SHIFT) \
                                                    | (CyUAB_CLK_PHI4 << CyUAB_SW_AV_MODBIT_SHIFT))

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CA_TOP ((CyUAB_CLK_PHI5 << CyUAB_SW_SA_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_RA_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_GA_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_VA_MODBIT_SHIFT)) /* Switch S0A */

    /* Cp branch switches */
    #define Filter_1_UABH_A_ALL_OPEN_CC_IN0     (uint32)((CyUAB_CLK_PHI4 << CyUAB_SW_C0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CQ_SHIFT))

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN0 ((Filter_1_UABH_A_ALL_OPEN_CC_IN0 \
                                                    &   ~((uint32)CyUAB_CLOCK_MASK  << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) \
                                                    |   (CyUAB_CLK_PHI4 << (Filter_1_UABH_A_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) /* Switch C00 for Vin00 */

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CC_IN1 ((CyUAB_CLK_PHI4 << CyUAB_SW_CG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CV_MODBIT_SHIFT)) /* Switch C0G */

    #define Filter_1_UABH_A_HIGHQSTAT_SW_CC_TOP ((CyUAB_CLK_PHI5 << CyUAB_SW_TC_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_RC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_GC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_VC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_ZC_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_SC_SHIFT)) /* Switch T0C, G0C, S0C */
    /* CA branch switches */
    #define Filter_1_UABH_A_HIGHQSTAT_SW_CF_BOT ((CyUAB_CLK_PHI5 << CyUAB_SW_PF_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_GF_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_PS_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_PO_SHIFT)) /* Switch P0F */


    /* Cpp or Cppp branch switches */
    #define Filter_1_UABH_B_ALL_OPEN_CB_IN0     (uint32)((CyUAB_CLK_PHI4 << CyUAB_SW_B0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_B3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BQ_SHIFT))

    #define Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN0 ((Filter_1_UABH_B_ALL_OPEN_CB_IN0 \
                                                    &   ~((uint32)CyUAB_CLOCK_MASK  << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) \
                                                    |   (CyUAB_CLK_PHI10 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT)))  /* Switch B10 for Vin10 */

    #define Filter_1_UABH_B_HIGHQSTAT_SW_CB_IN1 ((CyUAB_CLK_PHI9 << CyUAB_SW_BG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BB_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_BV_MODBIT_SHIFT))   /* Switch B1G */

    #define Filter_1_UABH_B_HIGHQDYN_SW_CB_TOP ((CyUAB_CLK_PHI1 << CyUAB_SW_SB_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_RB_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_VB_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI2 << CyUAB_SW_GB_MODBIT_SHIFT) \
                                                    |  ((1UL < Filter_1_FILTER_GT_Cpp_DENOMINATOR_VAL_PRE) \
                                                        ? (CyUAB_CLK_PHI2 << CyUAB_SW_TB_SHIFT) \
                                                        : (CyUAB_CLK_PHI5 << CyUAB_SW_TB_SHIFT)))  /* Switch S1B, G1B, T1B */

    /* C1 branch switches */
    #define Filter_1_UABH_B_ALL_OPEN_CC_IN0     (uint32)((CyUAB_CLK_PHI4 << CyUAB_SW_C0_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C1_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C2_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_C3_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CP_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CQ_SHIFT))

    #if (Filter_1_FILTER_GT_C1_NUMERATOR_VAL > 0UL)
        #define Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN0 ((Filter_1_UABH_B_ALL_OPEN_CC_IN0 \
                                                    &   ~((uint32)CyUAB_CLOCK_MASK  << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT))) \
                                                    |   (CyUAB_CLK_PHI10 << (Filter_1_UABH_B_halfuab__X0 << Filter_1_INPUT_SEL_SHIFT)))    /* Switch C10 for Vin10 */

        #define Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN1 ((CyUAB_CLK_PHI9 << CyUAB_SW_CG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CR_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CV_MODBIT_SHIFT))   /* Switch C1G */

        #define Filter_1_UABH_B_HIGHQDYN_SW_CC_TOP ((CyUAB_CLK_PHI1 << CyUAB_SW_ZC_SHIFT) \
                                                    |  (CyUAB_CLK_PHI2 << CyUAB_SW_GC_MODBIT_SHIFT) \
                                                    |  ((1UL < Filter_1_FILTER_GT_C1_DENOMINATOR_VAL) \
                                                        ? (CyUAB_CLK_PHI2 << CyUAB_SW_TC_SHIFT) \
                                                        : (CyUAB_CLK_PHI5 << CyUAB_SW_TC_SHIFT)))  /* Switch S01, G1C, T1C */
    #else /* C1 branch is disconnected (i.e. bandpass), so open all switches */
        #define Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN0 (Filter_1_UABH_B_ALL_OPEN_CC_IN0)
        #define Filter_1_UABH_B_HIGHQSTAT_SW_CC_IN1 ((CyUAB_CLK_PHI4 << CyUAB_SW_CG_MODBIT_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CC_SHIFT) \
                                                    |   (CyUAB_CLK_PHI4 << CyUAB_SW_CV_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_CR_MODBIT_SHIFT))

        #define Filter_1_UABH_B_HIGHQDYN_SW_CC_TOP ((CyUAB_CLK_PHI4 << CyUAB_SW_ZC_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_RC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_GC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_VC_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_SC_SHIFT)    \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_TC_SHIFT))  /* Switch S01, G1C, T1C */
    #endif /* (Filter_1_FILTER_GT_C1_NUMERATOR_VAL > 0UL) */

    /* C3 branch switches */
    #define Filter_1_UABH_B_HIGHQSTAT_SW_CA_IN0 ((CyUAB_CLK_PHI1 << CyUAB_SW_AQ_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_A0_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_A1_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_A2_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_A3_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_AP_SHIFT))   /* Switch A1Q */

    #define Filter_1_UABH_B_HIGHQSTAT_SW_CA_IN1 ((CyUAB_CLK_PHI2 << CyUAB_SW_AG_MODBIT_SHIFT)   \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_AA_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_AR_MODBIT_SHIFT) \
                                                    |  (CyUAB_CLK_PHI4 << CyUAB_SW_AV_MODBIT_SHIFT))    /* Switch A1G */

    #define Filter_1_UABH_B_HIGHQSTAT_SW_CA_TOP ((CyUAB_CLK_PHI1 << CyUAB_SW_GA_MODBIT_SHIFT) \
                                                |    (CyUAB_CLK_PHI4 << CyUAB_SW_RA_MODBIT_SHIFT) \
                                                |    (CyUAB_CLK_PHI4 << CyUAB_SW_VA_MODBIT_SHIFT) \
                                                |    (CyUAB_CLK_PHI2 << CyUAB_SW_SA_SHIFT))         /* Switch G1A and S1A */

    /* CB branch and output switches */
    #define Filter_1_UABH_B_HIGHQSTAT_SW_CF_BOT ((CyUAB_CLK_PHI5 << CyUAB_SW_PF_SHIFT) \
                                                |    (CyUAB_CLK_PHI4 << CyUAB_SW_GF_SHIFT) \
                                                |    (CyUAB_CLK_PHI4 << CyUAB_SW_PS_SHIFT) \
                                                |    (CyUAB_CLK_PHI3  << CyUAB_SW_PO_SHIFT))    /* Switch Q1F and Q10 */

#endif /* (Filter_1_FILTER_TOPOLOGY_USED == Filter_1_FILTER_TOPOLOGY_LOW_Q)*/


/***************************************
* Filter trim constants and macros
***************************************/

#define Filter_1_OPAMP_TRIM_POS_BASE     (0x00UL)
#define Filter_1_OPAMP_TRIM_POS_LIMIT    (0x08UL)
#define Filter_1_OPAMP_TRIM_NEG_BASE     (Filter_1_OPAMP_TRIM_POS_LIMIT)
#define Filter_1_OPAMP_TRIM_NEG_LIMIT    (0x10UL)
#define Filter_1_OPAMP_TRIM_MASK         (0x0FUL)

#define Filter_1_AGND_TRIM_POS_BASE      (0x00UL)
#define Filter_1_AGND_TRIM_POS_LIMIT     (0x10UL)
#define Filter_1_AGND_TRIM_NEG_BASE      (Filter_1_AGND_TRIM_POS_LIMIT)
#define Filter_1_AGND_TRIM_NEG_LIMIT     (0x20UL)
#define Filter_1_AGND_TRIM_MASK          (0x1FUL)


/***************************************
* Output buffer macros
***************************************/

#define Filter_1_CTB_CTRL_REG       (*(reg32 *) Filter_1_cy_psoc4_abuf__CTB_CTB_CTRL)
#define Filter_1_OA_RES_CTRL_REG    (*(reg32 *) Filter_1_cy_psoc4_abuf__OA_RES_CTRL)
#define Filter_1_OA_COMP_TRIM_REG   (*(reg32 *) Filter_1_cy_psoc4_abuf__OA_COMP_TRIM)
#define Filter_1_COMP_STAT_REG      (*(reg32 *) Filter_1_cy_psoc4_abuf__COMP_STAT)

#define Filter_1_OA_COMP_TRIM_VALUE         (3UL)

#define Filter_1_CTB_CTRL_ENABLED_SHIFT     (31UL)   /* [31]    Enable of the CTB IP */
#define Filter_1_OA_PWR_MODE_SHIFT          (0UL)    /* [1:0]   Power level */
#define Filter_1_OA_DRIVE_STR_SEL_SHIFT     (2UL)    /* [2]     Opamp output strength select: 0 - 1x, 1 - 10x */
#define Filter_1_OA_COMP_EN_SHIFT           (4UL)    /* [4]     CTB IP mode: 0 - Opamp, 1 - Comparator  */
#define Filter_1_OA_HYST_EN_SHIFT           (5UL)    /* [5]     Hysteresis enable  */
#define Filter_1_OA_DSI_LEVEL_SHIFT         (7UL)   /* [11]    Pump enable */
#define Filter_1_OA_PUMP_EN_SHIFT           (11UL)   /* [11]    Pump enable */
#define Filter_1_COMP_SHIFT                 ((Filter_1_cy_psoc4_abuf__OA_NUMBER == 1U) ? 16UL : 0UL)


#define Filter_1_CTB_CTRL_ENABLED           ((uint32) 0x01UL << Filter_1_CTB_CTRL_ENABLED_SHIFT)
#define Filter_1_OA_PWR_MODE_HIGH           ((uint32) 0x03UL << Filter_1_OA_PWR_MODE_SHIFT)
#define Filter_1_OA_PWR_MODE_MASK           ((uint32) 0x03UL << Filter_1_OA_PWR_MODE_SHIFT)
#define Filter_1_OA_DRIVE_STR_SEL_10X       ((uint32) 0x01UL << Filter_1_OA_DRIVE_STR_SEL_SHIFT)
#define Filter_1_OA_COMP_EN                 ((uint32) 0x01UL << Filter_1_OA_COMP_EN_SHIFT)
#define Filter_1_OA_HYST_EN                 ((uint32) 0x01UL << Filter_1_OA_HYST_EN_SHIFT)
#define Filter_1_OA_DSI_LEVEL               ((uint32) 0x01UL << Filter_1_OA_DSI_LEVEL_SHIFT)
#define Filter_1_OA_PUMP_EN                 ((uint32) 0x01UL << Filter_1_OA_PUMP_EN_SHIFT)
#define Filter_1_COMP_MASK                  ((uint32) 0x01UL << Filter_1_COMP_SHIFT)

#endif /* !defined(CY_Filter_1_FILTER_H) */


/* [] END OF FILE */
