/***************************************************************************//**
* \file     Filter_1_PM.c
* \version  1.10
*
* \brief
* Provides the power manager source code to the API for the Filter_1 Component.
*
********************************************************************************
* \copyright
* (c) 2018, Cypress Semiconductor Corporation. All rights reserved.
* This software, including source code, documentation and related
* materials ("Software"), is owned by Cypress Semiconductor
* Corporation ("Cypress") and is protected by and subject to worldwide
* patent protection (United States and foreign), United States copyright
* laws and international treaty provisions. Therefore, you may use this
* Software only as provided in the license agreement accompanying the
* software package from which you obtained this Software ("EULA").
* If no EULA applies, Cypress hereby grants you a personal, nonexclusive,
* non-transferable license to copy, modify, and compile the
* Software source code solely for use in connection with Cypress's
* integrated circuit products. Any reproduction, modification, translation,
* compilation, or representation of this Software except as specified
* above is prohibited without the express written permission of Cypress.
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO
* WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING,
* BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
* PARTICULAR PURPOSE. Cypress reserves the right to make
* changes to the Software without notice. Cypress does not assume any
* liability arising out of the application or use of the Software or any
* product or circuit described in the Software. Cypress does not
* authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer
* of such system or application assumes all risk of such use and in doing
* so agrees to indemnify Cypress against all liability.
*******************************************************************************/

#include "Filter_1.h"

/** Preserves whether the UAB was enabled prior to sleep. */
static uint8 Filter_1_enableStateBackup;


/*******************************************************************************
* Function Name: Filter_1_Sleep
****************************************************************************//**
*
* \par
* Disable block operation and saves its configuration. Should be called
* just prior to entering sleep.
*
*******************************************************************************/
void Filter_1_Sleep(void)
{
    /* Check the enable bit for the UAB block. */
    if( 0UL != (Filter_1_UABH_A_UAB_CTRL_REG & Filter_1_UABH_A_ENABLED_MASK))
    {
        /* Component is enabled. */
        Filter_1_enableStateBackup = 1U;

        /* Stop the Component. */
        Filter_1_Stop();
    }
    else
    {
        /* Component is disabled. */
        Filter_1_enableStateBackup = 0U;
    }
}


/*******************************************************************************
* Function Name: Filter_1_Wakeup
****************************************************************************//**
*
* \par
* Enable block operation and restores its configuration. Should be called
* just after awaking from sleep.
*
*******************************************************************************/
void Filter_1_Wakeup(void)
{
    /* Enable the Component if it was enabled before entering low power. */
    if(0U != Filter_1_enableStateBackup)
    {
        Filter_1_Enable();

    } /* Do nothing if Component was disable before. */
}


/* [] END OF FILE */
