/*******************************************************************************
* File Name: Filterl_I.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Filterl_I.h"

static Filterl_I_BACKUP_STRUCT  Filterl_I_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Filterl_I_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Filterl_I_SUT.c usage_Filterl_I_Sleep_Wakeup
*******************************************************************************/
void Filterl_I_Sleep(void)
{
    #if defined(Filterl_I__PC)
        Filterl_I_backup.pcState = Filterl_I_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Filterl_I_backup.usbState = Filterl_I_CR1_REG;
            Filterl_I_USB_POWER_REG |= Filterl_I_USBIO_ENTER_SLEEP;
            Filterl_I_CR1_REG &= Filterl_I_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Filterl_I__SIO)
        Filterl_I_backup.sioState = Filterl_I_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Filterl_I_SIO_REG &= (uint32)(~Filterl_I_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Filterl_I_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Filterl_I_Sleep() for an example usage.
*******************************************************************************/
void Filterl_I_Wakeup(void)
{
    #if defined(Filterl_I__PC)
        Filterl_I_PC = Filterl_I_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Filterl_I_USB_POWER_REG &= Filterl_I_USBIO_EXIT_SLEEP_PH1;
            Filterl_I_CR1_REG = Filterl_I_backup.usbState;
            Filterl_I_USB_POWER_REG &= Filterl_I_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Filterl_I__SIO)
        Filterl_I_SIO_REG = Filterl_I_backup.sioState;
    #endif
}


/* [] END OF FILE */
