/* ========================================
 *
 * Copyright Infineon 2021
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Infineon.
 *
 * Project FilterTest_4_2_2 for CY8C4A45LQI-483
 * Project also fits on CY8C4145LQI0PS483 on CY8CKIT-147
 *
 * Project created by Dennis Seguine, Sr Member of Technical Staff
 *
 * Project steps through 2-pole low-pass filters at 2.0, 3.0, and 4.0kHz
 * Connect external pull-up resistor from P0.4 to Vdd.
 * Press SW1 (on P0.3) to step through filter configurations.
 * 
 * Filters are done by directly writing capacitor values into
 *   registers 0x40340208 and 0x40340308.
 * Direct write values were determined by building separate filters
 *  at each frequency and recording the ABCFx_Val register values
 *  for each filter, then constructing the tables.
 * Other filter values must be obtained in a similar manner, run-time
 *  calculate of capacitor and register values is not practical.
 * Filters are designed for unity positive gain. To change gain polarity,
 *  change PWM1_line output from direct output to inverse output.
 * Negative polarity filters offer opportunity to add a zero in the
 *  the transfer function to specific frequencies as determined in the
 *  configuration tool.
 * DC performance was not tested. Calling the trim function may be
 *  required to guarantee DC performance. Testing will demonstrate.
 *
 * Testing was done using Agilent 33220A Function Generator, sweeping
 *  from 10 Hz to 10.0 kHz. Obviously a network analyzer would do a
 *  better job. Measurements were done with scope, triggered by Sync
 *  output of generator
 * This is a prototype project, it does not purport to follow standard
 *  best-practice programming techniques, it is not optimized for
 *  power or programming efficiency.
 * ========================================
*/
#include <project.h>

uint8 StepIntFlag;
uint8 ToggleFlag;
uint8 ConfigCount;
uint32 ABCF0[5];
uint32 ABCF1[5];
uint32 ABCF0add;
uint32 ABCF1add;

CY_ISR(INT_ISR_isr_Step) // ISR triggers on change on Step .. P0.3
{ 
    StepIntFlag = 1;
    Step_ClearInterrupt();
}

int main()
{
    PVref_1_Start();
    Filter_1_Start();
    ABCF0add = 0x40340208;
    ABCF0[0] = 0x18030c43;  //2k
    ABCF0[1] = 0x1c060d86;  //3k
    ABCF0[2] = 0x1f090f09;  //4k

    ABCF1add = 0x40340308;
    ABCF1[0] = 0x1a000104;  //2k
    ABCF1[1] = 0x1d0001c7;  //3k
    ABCF1[2] = 0x1a000208;  //4k
    
    ToggleFlag = 0;
    isr_Step_StartEx(INT_ISR_isr_Step);
     
    CyGlobalIntEnable; /* Enable global interrupts. */
  
    CyDelay(50);
    PWM_1_Start();
    ConfigCount = 0;   

    for(;;)
    {
        /* Place your application code here. */    
    if(StepIntFlag == 1)
        {
            CyDelay(100);  //provides switch debounce delay
            StepIntFlag = 0;
            if(ToggleFlag == 0)
                {
                    ToggleFlag = 1;
                    LED_Write(1);
                }
            else
                {
                    ToggleFlag = 0;
                    LED_Write(0);
                }
            // Step through configs            
            if(ConfigCount < 3)
                {
                CY_SET_REG32(ABCF0add,ABCF0[ConfigCount]);
                CY_SET_REG32(ABCF1add,ABCF1[ConfigCount]);
                ConfigCount += 1;
                }
            else
                {
                    ConfigCount = 0;
                }
        }
    }
}
   
/* [] END OF FILE */
